generalhoslem-package:
\Sexpr[results=rd,stage=build]{tools:::Rd_package_title("#1")}generalhoslemHosmer-Lemeshow Test for Binary and Multinomial Logistic Models
Description
\Sexpr[results=rd,stage=build]{tools:::Rd_package_description("#1")}generalhoslemContains a sole function that performs the Hosmer-Lemeshow test for binary and multinomial logistic regression models. It implements the classic Hosmer-Lemeshow test as well as its multinomial generalisation, both of which are described in Hosmer, Lemeshow and Sturdivant (2013).
Arguments
Details
\Sexpr[results=rd,stage=build]{tools:::Rd_package_DESCRIPTION("#1")}generalhoslemThis package was not yet installed at build time.
\Sexpr[results=rd,stage=build]{tools:::Rd_package_indices("#1")}generalhoslem
Index: This package was not yet installed at build time.
References
Fagerland MW, Hosmer DW, Bofin AM. Multinomial goodness-of-fit tests for logistic regression models. Statistics in medicine 2008;27(21):4238-53.
Hosmer DW, Lemeshow S, Sturdivant RX. Applied Logistic Regression, 3rd Edition. 2013. New York, USA: John Wiley and Sons.